.. _parsers:

=======
Parsers
=======

This section describes classes for parsing CLI outputs of network devices to structured objects - dictionaries.

.. _cli_parsers:

CLI Parsers
===========

.. toctree::
   :maxdepth: 2

   ParserModule
